@@ -164,8 +164,6 @@ public:
   virtual ~ObjectiveConfig() {}
   double sigmoid = 1.0f;
   double fair_c = 1.0f;
-  // for Approximate Hessian With Gaussian
-  double gaussian_eta = 1.0f;
   double poisson_max_delta_step = 0.7f;
   // for lambdarank
   std::vector<double> label_gain;
@@ -180,6 +178,7 @@ public:
   // True will sqrt fit the sqrt(label)
   bool reg_sqrt = false;
   double alpha = 0.9f;
+  double tweedie_variance_power = 1.5f;
   LIGHTGBM_EXPORT void Set(const std::unordered_map<std::string, std::string>& params) override;
 };
 
@@ -191,6 +190,7 @@ public:
   double sigmoid = 1.0f;
   double fair_c = 1.0f;
   double alpha = 0.9f;
+  double tweedie_variance_power = 1.5f;
   std::vector<double> label_gain;
   std::vector<int> eval_at;
   LIGHTGBM_EXPORT void Set(const std::unordered_map<std::string, std::string>& params) override;
@@ -239,7 +239,6 @@ public:
 struct BoostingConfig: public ConfigBase {
 public:
   virtual ~BoostingConfig() {}
-  double sigmoid = 1.0f;
   int output_freq = 1;
   bool is_provide_training_metric = false;
   int num_iterations = 100;
@@ -445,6 +444,7 @@ struct ParameterAlias {
       { "workers", "machines" },
       { "nodes", "machines" },
       { "subsample_for_bin", "bin_construct_sample_cnt" },
+      { "metric_freq", "output_freq" }
     });
     const std::unordered_set<std::string> parameter_set({
       "config", "config_file", "task", "device",
@@ -468,16 +468,16 @@ struct ParameterAlias {
       "pred_early_stop_margin", "use_missing", "sigmoid",
       "fair_c", "poission_max_delta_step", "scale_pos_weight",
       "boost_from_average", "max_position", "label_gain",
-      "metric", "metric_freq", "time_out",
+      "metric", "output_freq", "time_out",
       "gpu_platform_id", "gpu_device_id", "gpu_use_dp",
       "convert_model", "convert_model_language",
       "feature_fraction_seed", "enable_bundle", "data_filename", "valid_data_filenames",
       "snapshot_freq", "verbosity", "sparse_threshold", "enable_load_from_binary_file",
-      "max_conflict_rate", "poisson_max_delta_step", "gaussian_eta",
-      "histogram_pool_size", "output_freq", "is_provide_training_metric", "machine_list_filename", "machines",
+      "max_conflict_rate", "poisson_max_delta_step",
+      "histogram_pool_size", "is_provide_training_metric", "machine_list_filename", "machines",
       "zero_as_missing", "init_score_file", "valid_init_score_file", "is_predict_contrib",
       "max_cat_threshold",  "cat_smooth", "min_data_per_group", "cat_l2", "max_cat_to_onehot",
-      "alpha", "reg_sqrt"
+      "alpha", "reg_sqrt", "tweedie_variance_power"
     });
     std::unordered_map<std::string, std::string> tmp_map;
     for (const auto& pair : *params) {
