@@ -35,12 +35,29 @@ public:
   static BruckMap Construct(int rank, int num_machines);
 };
 
+/*!
+* \brief node type on recursive halving algorithm
+*        When number of machines is not power of 2, need group machines into power of 2 group.
+*        And we can let each group has at most 2 machines.
+*        if the group only has 1 machine. this machine is the normal node
+*        if the group has 2 machines, this group will have two type of nodes, one is the leader.
+*        leader will represent this group and communication with others.
+*/
+enum RecursiveHalvingNodeType {
+  Normal,  // normal node, 1 group only have 1 machine
+  GroupLeader,  // leader of group when number of machines in this group is 2.
+  Other  // non-leader machines in group
+};
+
 /*! \brief Network structure for recursive halving algorithm */
 class RecursiveHalvingMap {
 public:
-  bool need_pairwise;
   /*! \brief Communication times for one recursize halving algorithm  */
   int k;
+  /*! \brief Node type */
+  RecursiveHalvingNodeType type;
+  bool is_power_of_2;
+  int neighbor;
   /*! \brief ranks[i] means the machines that will communicate with on i-th communication*/
   std::vector<int> ranks;
   /*! \brief  send_block_start[i] means send block start index at i-th communication*/
@@ -54,7 +71,7 @@ public:
 
   RecursiveHalvingMap();
 
-  RecursiveHalvingMap(int k, bool in_need_pairwise);
+  RecursiveHalvingMap(int k, RecursiveHalvingNodeType _type, bool _is_power_of_2);
 
   /*!
   * \brief Create the object of recursive halving map
@@ -193,7 +210,68 @@ public:
     return global;
   }
 
+  template<class T>
+  static T GlobalSyncUpByMean(T& local) {
+    T global = (T)0;
+    Allreduce(reinterpret_cast<char*>(&local),
+              sizeof(local), sizeof(local),
+              reinterpret_cast<char*>(&global),
+              [](const char* src, char* dst, int type_size, comm_size_t len) {
+      comm_size_t used_size = 0;
+      const T *p1;
+      T *p2;
+      while (used_size < len) {
+        p1 = reinterpret_cast<const T *>(src);
+        p2 = reinterpret_cast<T *>(dst);
+        *p2 += *p1;
+        src += type_size;
+        dst += type_size;
+        used_size += type_size;
+      }
+    });
+    return static_cast<T>(global / num_machines_);
+  }
+
+  template<class T>
+  static void GlobalSum(std::vector<T>& local) {
+    std::vector<T> global;
+    Allreduce(reinterpret_cast<char*>(local.data()),
+              static_cast<comm_size_t>(sizeof(T) * local.size()), sizeof(T),
+              reinterpret_cast<char*>(global.data()),
+              [](const char* src, char* dst, int type_size, comm_size_t len) {
+      comm_size_t used_size = 0;
+      const T *p1;
+      T *p2;
+      while (used_size < len) {
+        p1 = reinterpret_cast<const T *>(src);
+        p2 = reinterpret_cast<T *>(dst);
+        *p2 += *p1;
+        src += type_size;
+        dst += type_size;
+        used_size += type_size;
+      }
+    });
+    for (size_t i = 0; i < local.size(); ++i) {
+      local[i] = global[i];
+    }
+  }
+
 private:
+
+  static void AllgatherBruck(char* input, const comm_size_t* block_start, const comm_size_t* block_len, char* output, comm_size_t all_size);
+
+  static void AllgatherRecursiveDoubling(char* input, const comm_size_t* block_start, const comm_size_t* block_len, char* output, comm_size_t all_size);
+
+  static void AllgatherRing(char* input, const comm_size_t* block_start, const comm_size_t* block_len, char* output, comm_size_t all_size);
+
+  static void ReduceScatterRecursiveHalving(char* input, comm_size_t input_size, int type_size,
+                                            const comm_size_t* block_start, const comm_size_t* block_len, char* output, comm_size_t output_size,
+                                            const ReduceFunction& reducer);
+
+  static void ReduceScatterRing(char* input, comm_size_t input_size, int type_size,
+                                const comm_size_t* block_start, const comm_size_t* block_len, char* output, comm_size_t output_size,
+                                const ReduceFunction& reducer);
+
   /*! \brief Number of all machines */
   static THREAD_LOCAL int num_machines_;
   /*! \brief Rank of local machine */
