@@ -254,7 +254,7 @@ void Application::Predict() {
 void Application::InitPredict() {
   boosting_.reset(
     Boosting::CreateBoosting("gbdt", config_.io_config.input_model.c_str()));
-  Log::Info("Finished initializing prediction");
+  Log::Info("Finished initializing prediction, total used %d iterations", boosting_->GetCurrentIteration());
 }
 
 void Application::ConvertModel() {
