@@ -96,6 +96,9 @@ private:
         for (int i = 0; i < iter_; ++i) {
           if (random_for_drop_.NextFloat() < drop_rate * tree_weight_[i] * inv_average_weight) {
             drop_index_.push_back(num_init_iteration_ + i);
+            if (drop_index_.size() >= static_cast<size_t>(gbdt_config_->max_drop)) {
+              break;
+            }
           }
         }
       } else {
@@ -105,6 +108,9 @@ private:
         for (int i = 0; i < iter_; ++i) {
           if (random_for_drop_.NextFloat() < drop_rate) {
             drop_index_.push_back(num_init_iteration_ + i);
+            if (drop_index_.size() >= static_cast<size_t>(gbdt_config_->max_drop)) {
+              break;
+            }
           }
         }
       }
